# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/organization_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import organization_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/organization_service.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>yandex/cloud/organizationmanager/v1/organization_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/organization.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"?\n\x16GetOrganizationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"t\n\x18ListOrganizationsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"~\n\x19ListOrganizationsResponse\x12H\n\rorganizations\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.Organization\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe1\x01\n\x19UpdateOrganizationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x18\n\x05title\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\"5\n\x1aUpdateOrganizationMetadata\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"\x88\x01\n!ListOrganizationOperationsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListOrganizationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa0\x0c\n\x13OrganizationService\x12\xb7\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.GetOrganizationRequest\x1a\x31.yandex.cloud.organizationmanager.v1.Organization\"@\x82\xd3\xe4\x93\x02:\x12\x38/organization-manager/v1/organizations/{organization_id}\x12\xb5\x01\n\x04List\x12=.yandex.cloud.organizationmanager.v1.ListOrganizationsRequest\x1a>.yandex.cloud.organizationmanager.v1.ListOrganizationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/organization-manager/v1/organizations\x12\xde\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest\x1a!.yandex.cloud.operation.Operation\"q\x82\xd3\xe4\x93\x02=28/organization-manager/v1/organizations/{organization_id}:\x01*\xb2\xd2**\n\x1aUpdateOrganizationMetadata\x12\x0cOrganization\x12\xee\x01\n\x0eListOperations\x12\x46.yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest\x1aG.yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/organization-manager/v1/organizations/{organization_id}/operations\x12\xc6\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/organization-manager/v1/organizations/{resource_id}:listAccessBindings\x12\xf6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02K\"F/organization-manager/v1/organizations/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\x82\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/organizations/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='GetOrganizationRequest',
  full_name='yandex.cloud.organizationmanager.v1.GetOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.GetOrganizationRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=425,
)


_LISTORGANIZATIONSREQUEST = _descriptor.Descriptor(
  name='ListOrganizationsRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=543,
)


_LISTORGANIZATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOrganizationsResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizations', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsResponse.organizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=671,
)


_UPDATEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='UpdateOrganizationRequest',
  full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=899,
)


_UPDATEORGANIZATIONMETADATA = _descriptor.Descriptor(
  name='UpdateOrganizationMetadata',
  full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.UpdateOrganizationMetadata.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=901,
  serialized_end=954,
)


_LISTORGANIZATIONOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOrganizationOperationsRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1093,
)


_LISTORGANIZATIONOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOrganizationOperationsResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1211,
)

_LISTORGANIZATIONSRESPONSE.fields_by_name['organizations'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2._ORGANIZATION
_UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTORGANIZATIONOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetOrganizationRequest'] = _GETORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsRequest'] = _LISTORGANIZATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsResponse'] = _LISTORGANIZATIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateOrganizationRequest'] = _UPDATEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateOrganizationMetadata'] = _UPDATEORGANIZATIONMETADATA
DESCRIPTOR.message_types_by_name['ListOrganizationOperationsRequest'] = _LISTORGANIZATIONOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationOperationsResponse'] = _LISTORGANIZATIONOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetOrganizationRequest = _reflection.GeneratedProtocolMessageType('GetOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GetOrganizationRequest)
  })
_sym_db.RegisterMessage(GetOrganizationRequest)

ListOrganizationsRequest = _reflection.GeneratedProtocolMessageType('ListOrganizationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListOrganizationsRequest)
  })
_sym_db.RegisterMessage(ListOrganizationsRequest)

ListOrganizationsResponse = _reflection.GeneratedProtocolMessageType('ListOrganizationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListOrganizationsResponse)
  })
_sym_db.RegisterMessage(ListOrganizationsResponse)

UpdateOrganizationRequest = _reflection.GeneratedProtocolMessageType('UpdateOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest)
  })
_sym_db.RegisterMessage(UpdateOrganizationRequest)

UpdateOrganizationMetadata = _reflection.GeneratedProtocolMessageType('UpdateOrganizationMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateOrganizationMetadata)
  })
_sym_db.RegisterMessage(UpdateOrganizationMetadata)

ListOrganizationOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOrganizationOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest)
  })
_sym_db.RegisterMessage(ListOrganizationOperationsRequest)

ListOrganizationOperationsResponse = _reflection.GeneratedProtocolMessageType('ListOrganizationOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.organization_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse)
  })
_sym_db.RegisterMessage(ListOrganizationOperationsResponse)


DESCRIPTOR._options = None
_GETORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
_LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTORGANIZATIONSREQUEST.fields_by_name['filter']._options = None
_UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
_UPDATEORGANIZATIONREQUEST.fields_by_name['name']._options = None
_UPDATEORGANIZATIONREQUEST.fields_by_name['description']._options = None
_UPDATEORGANIZATIONREQUEST.fields_by_name['title']._options = None
_LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['organization_id']._options = None
_LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_ORGANIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OrganizationService',
  full_name='yandex.cloud.organizationmanager.v1.OrganizationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1214,
  serialized_end=2782,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.Get',
    index=0,
    containing_service=None,
    input_type=_GETORGANIZATIONREQUEST,
    output_type=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2._ORGANIZATION,
    serialized_options=b'\202\323\344\223\002:\0228/organization-manager/v1/organizations/{organization_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.List',
    index=1,
    containing_service=None,
    input_type=_LISTORGANIZATIONSREQUEST,
    output_type=_LISTORGANIZATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/organization-manager/v1/organizations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.Update',
    index=2,
    containing_service=None,
    input_type=_UPDATEORGANIZATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=28/organization-manager/v1/organizations/{organization_id}:\001*\262\322**\n\032UpdateOrganizationMetadata\022\014Organization',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.ListOperations',
    index=3,
    containing_service=None,
    input_type=_LISTORGANIZATIONOPERATIONSREQUEST,
    output_type=_LISTORGANIZATIONOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002E\022C/organization-manager/v1/organizations/{organization_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.ListAccessBindings',
    index=4,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002I\022G/organization-manager/v1/organizations/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.SetAccessBindings',
    index=5,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002K\"F/organization-manager/v1/organizations/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.OrganizationService.UpdateAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002N\"I/organization-manager/v1/organizations/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORGANIZATIONSERVICE)

DESCRIPTOR.services_by_name['OrganizationService'] = _ORGANIZATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/elasticsearch/v1/auth_service.proto',
  package='yandex.cloud.mdb.elasticsearch.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4yandex/cloud/mdb/elasticsearch/v1/auth_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/elasticsearch/v1/auth.proto\"<\n\x18ListAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"_\n\x19ListAuthProvidersResponse\x12\x42\n\tproviders\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"j\n\x16GetAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\"\x89\x01\n\x17\x41\x64\x64\x41uthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"\x8c\x01\n\x1aUpdateAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"|\n\x1a\x44\x65leteAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0eprovider_names\x18\x02 \x03(\tB$\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\"\xb6\x01\n\x19UpdateAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x12G\n\x08provider\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x04\xe8\xc7\x31\x01\"m\n\x19\x44\x65leteAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\"=\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1bUpdateAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t2\xef\x0c\n\x0b\x41uthService\x12\xd2\x01\n\rListProviders\x12;.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest\x1a<.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\x12\xc8\x01\n\x0bGetProvider\x12\x39.yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest\x1a/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"M\x82\xd3\xe4\x93\x02G\x12\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}\x12\xe5\x01\n\x0c\x41\x64\x64Providers\x12:.yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"v\x82\xd3\xe4\x93\x02\x43\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\xb2\xd2*)\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\rAuthProviders\x12\xee\x01\n\x0fUpdateProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"y\x82\xd3\xe4\x93\x02\x43\x1a>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x12\xf3\x01\n\x0f\x44\x65leteProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"~\x82\xd3\xe4\x93\x02@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.Empty\x12\xf4\x01\n\x0eUpdateProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\x82\xd3\xe4\x93\x02J\x1a\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\x01*\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x12\xf9\x01\n\x0e\x44\x65leteProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\x82\xd3\xe4\x93\x02G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.EmptyB|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2.DESCRIPTOR,])




_LISTAUTHPROVIDERSREQUEST = _descriptor.Descriptor(
  name='ListAuthProvidersRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=332,
)


_LISTAUTHPROVIDERSRESPONSE = _descriptor.Descriptor(
  name='ListAuthProvidersResponse',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=429,
)


_GETAUTHPROVIDERREQUEST = _descriptor.Descriptor(
  name='GetAuthProviderRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50\362\3071\020[a-z][a-z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=537,
)


_ADDAUTHPROVIDERSREQUEST = _descriptor.Descriptor(
  name='AddAuthProvidersRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='providers', full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest.providers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=677,
)


_UPDATEAUTHPROVIDERSREQUEST = _descriptor.Descriptor(
  name='UpdateAuthProvidersRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='providers', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest.providers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=820,
)


_DELETEAUTHPROVIDERSREQUEST = _descriptor.Descriptor(
  name='DeleteAuthProvidersRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_names', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest.provider_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10\212\3101\004<=50\362\3071\020[a-z][a-z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=946,
)


_UPDATEAUTHPROVIDERREQUEST = _descriptor.Descriptor(
  name='UpdateAuthProviderRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50\362\3071\020[a-z][a-z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest.provider', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1131,
)


_DELETEAUTHPROVIDERREQUEST = _descriptor.Descriptor(
  name='DeleteAuthProviderRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50\362\3071\020[a-z][a-z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1242,
)


_ADDAUTHPROVIDERSMETADATA = _descriptor.Descriptor(
  name='AddAuthProvidersMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersMetadata.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1305,
)


_UPDATEAUTHPROVIDERSMETADATA = _descriptor.Descriptor(
  name='UpdateAuthProvidersMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersMetadata.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1371,
)


_DELETEAUTHPROVIDERSMETADATA = _descriptor.Descriptor(
  name='DeleteAuthProvidersMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersMetadata.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1373,
  serialized_end=1437,
)

_LISTAUTHPROVIDERSRESPONSE.fields_by_name['providers'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2._AUTHPROVIDER
_ADDAUTHPROVIDERSREQUEST.fields_by_name['providers'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2._AUTHPROVIDER
_UPDATEAUTHPROVIDERSREQUEST.fields_by_name['providers'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2._AUTHPROVIDER
_UPDATEAUTHPROVIDERREQUEST.fields_by_name['provider'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2._AUTHPROVIDER
DESCRIPTOR.message_types_by_name['ListAuthProvidersRequest'] = _LISTAUTHPROVIDERSREQUEST
DESCRIPTOR.message_types_by_name['ListAuthProvidersResponse'] = _LISTAUTHPROVIDERSRESPONSE
DESCRIPTOR.message_types_by_name['GetAuthProviderRequest'] = _GETAUTHPROVIDERREQUEST
DESCRIPTOR.message_types_by_name['AddAuthProvidersRequest'] = _ADDAUTHPROVIDERSREQUEST
DESCRIPTOR.message_types_by_name['UpdateAuthProvidersRequest'] = _UPDATEAUTHPROVIDERSREQUEST
DESCRIPTOR.message_types_by_name['DeleteAuthProvidersRequest'] = _DELETEAUTHPROVIDERSREQUEST
DESCRIPTOR.message_types_by_name['UpdateAuthProviderRequest'] = _UPDATEAUTHPROVIDERREQUEST
DESCRIPTOR.message_types_by_name['DeleteAuthProviderRequest'] = _DELETEAUTHPROVIDERREQUEST
DESCRIPTOR.message_types_by_name['AddAuthProvidersMetadata'] = _ADDAUTHPROVIDERSMETADATA
DESCRIPTOR.message_types_by_name['UpdateAuthProvidersMetadata'] = _UPDATEAUTHPROVIDERSMETADATA
DESCRIPTOR.message_types_by_name['DeleteAuthProvidersMetadata'] = _DELETEAUTHPROVIDERSMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAuthProvidersRequest = _reflection.GeneratedProtocolMessageType('ListAuthProvidersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTHPROVIDERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest)
  })
_sym_db.RegisterMessage(ListAuthProvidersRequest)

ListAuthProvidersResponse = _reflection.GeneratedProtocolMessageType('ListAuthProvidersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTHPROVIDERSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse)
  })
_sym_db.RegisterMessage(ListAuthProvidersResponse)

GetAuthProviderRequest = _reflection.GeneratedProtocolMessageType('GetAuthProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHPROVIDERREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest)
  })
_sym_db.RegisterMessage(GetAuthProviderRequest)

AddAuthProvidersRequest = _reflection.GeneratedProtocolMessageType('AddAuthProvidersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTHPROVIDERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest)
  })
_sym_db.RegisterMessage(AddAuthProvidersRequest)

UpdateAuthProvidersRequest = _reflection.GeneratedProtocolMessageType('UpdateAuthProvidersRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTHPROVIDERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest)
  })
_sym_db.RegisterMessage(UpdateAuthProvidersRequest)

DeleteAuthProvidersRequest = _reflection.GeneratedProtocolMessageType('DeleteAuthProvidersRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAUTHPROVIDERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest)
  })
_sym_db.RegisterMessage(DeleteAuthProvidersRequest)

UpdateAuthProviderRequest = _reflection.GeneratedProtocolMessageType('UpdateAuthProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTHPROVIDERREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest)
  })
_sym_db.RegisterMessage(UpdateAuthProviderRequest)

DeleteAuthProviderRequest = _reflection.GeneratedProtocolMessageType('DeleteAuthProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAUTHPROVIDERREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest)
  })
_sym_db.RegisterMessage(DeleteAuthProviderRequest)

AddAuthProvidersMetadata = _reflection.GeneratedProtocolMessageType('AddAuthProvidersMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTHPROVIDERSMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersMetadata)
  })
_sym_db.RegisterMessage(AddAuthProvidersMetadata)

UpdateAuthProvidersMetadata = _reflection.GeneratedProtocolMessageType('UpdateAuthProvidersMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTHPROVIDERSMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersMetadata)
  })
_sym_db.RegisterMessage(UpdateAuthProvidersMetadata)

DeleteAuthProvidersMetadata = _reflection.GeneratedProtocolMessageType('DeleteAuthProvidersMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAUTHPROVIDERSMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersMetadata)
  })
_sym_db.RegisterMessage(DeleteAuthProvidersMetadata)


DESCRIPTOR._options = None
_LISTAUTHPROVIDERSREQUEST.fields_by_name['cluster_id']._options = None
_GETAUTHPROVIDERREQUEST.fields_by_name['cluster_id']._options = None
_GETAUTHPROVIDERREQUEST.fields_by_name['name']._options = None
_ADDAUTHPROVIDERSREQUEST.fields_by_name['cluster_id']._options = None
_ADDAUTHPROVIDERSREQUEST.fields_by_name['providers']._options = None
_UPDATEAUTHPROVIDERSREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEAUTHPROVIDERSREQUEST.fields_by_name['providers']._options = None
_DELETEAUTHPROVIDERSREQUEST.fields_by_name['cluster_id']._options = None
_DELETEAUTHPROVIDERSREQUEST.fields_by_name['provider_names']._options = None
_UPDATEAUTHPROVIDERREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEAUTHPROVIDERREQUEST.fields_by_name['name']._options = None
_UPDATEAUTHPROVIDERREQUEST.fields_by_name['provider']._options = None
_DELETEAUTHPROVIDERREQUEST.fields_by_name['cluster_id']._options = None
_DELETEAUTHPROVIDERREQUEST.fields_by_name['name']._options = None

_AUTHSERVICE = _descriptor.ServiceDescriptor(
  name='AuthService',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1440,
  serialized_end=3087,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListProviders',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.ListProviders',
    index=0,
    containing_service=None,
    input_type=_LISTAUTHPROVIDERSREQUEST,
    output_type=_LISTAUTHPROVIDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProvider',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.GetProvider',
    index=1,
    containing_service=None,
    input_type=_GETAUTHPROVIDERREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2._AUTHPROVIDER,
    serialized_options=b'\202\323\344\223\002G\022E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddProviders',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.AddProviders',
    index=2,
    containing_service=None,
    input_type=_ADDAUTHPROVIDERSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*\262\322*)\n\030AddAuthProvidersMetadata\022\rAuthProviders',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProviders',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.UpdateProviders',
    index=3,
    containing_service=None,
    input_type=_UPDATEAUTHPROVIDERSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C\032>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProviders',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.DeleteProviders',
    index=4,
    containing_service=None,
    input_type=_DELETEAUTHPROVIDERSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProvider',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.UpdateProvider',
    index=5,
    containing_service=None,
    input_type=_UPDATEAUTHPROVIDERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002J\032E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\001*\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProvider',
    full_name='yandex.cloud.mdb.elasticsearch.v1.AuthService.DeleteProvider',
    index=6,
    containing_service=None,
    input_type=_DELETEAUTHPROVIDERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHSERVICE)

DESCRIPTOR.services_by_name['AuthService'] = _AUTHSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/format_schema_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import format_schema_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/format_schema_service.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/mdb/clickhouse/v1/format_schema_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x32yandex/cloud/mdb/clickhouse/v1/format_schema.proto\"v\n\x16GetFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"z\n\x18ListFormatSchemasRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"z\n\x19ListFormatSchemasResponse\x12\x44\n\x0e\x66ormat_schemas\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.FormatSchema\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x01\n\x19\x43reateFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x44\n\x04type\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.mdb.clickhouse.v1.FormatSchemaTypeB\x04\xe8\xc7\x31\x01\x12\x11\n\x03uri\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"L\n\x1a\x43reateFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t\"\xb7\x01\n\x19UpdateFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0b\n\x03uri\x18\x04 \x01(\t\"L\n\x1aUpdateFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t\"y\n\x19\x44\x65leteFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"L\n\x1a\x44\x65leteFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t2\xea\x08\n\x13\x46ormatSchemaService\x12\xc4\x01\n\x03Get\x12\x36.yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest\x1a,.yandex.cloud.mdb.clickhouse.v1.FormatSchema\"W\x82\xd3\xe4\x93\x02Q\x12O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}\x12\xbf\x01\n\x04List\x12\x38.yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest\x1a\x39.yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas\x12\xdb\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02?\":/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas:\x01*\xb2\xd2**\n\x1a\x43reateFormatSchemaMetadata\x12\x0c\x46ormatSchema\x12\xf1\x01\n\x06Update\x12\x39.yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02T2O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}:\x01*\xb2\xd2**\n\x1aUpdateFormatSchemaMetadata\x12\x0c\x46ormatSchema\x12\xf7\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02Q*O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}\xb2\xd2*3\n\x1a\x44\x65leteFormatSchemaMetadata\x12\x15google.protobuf.EmptyBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2.DESCRIPTOR,])




_GETFORMATSCHEMAREQUEST = _descriptor.Descriptor(
  name='GetFormatSchemaRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=433,
)


_LISTFORMATSCHEMASREQUEST = _descriptor.Descriptor(
  name='ListFormatSchemasRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=557,
)


_LISTFORMATSCHEMASRESPONSE = _descriptor.Descriptor(
  name='ListFormatSchemasResponse',
  full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format_schemas', full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse.format_schemas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=559,
  serialized_end=681,
)


_CREATEFORMATSCHEMAREQUEST = _descriptor.Descriptor(
  name='CreateFormatSchemaRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=894,
)


_CREATEFORMATSCHEMAMETADATA = _descriptor.Descriptor(
  name='CreateFormatSchemaMetadata',
  full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaMetadata.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=972,
)


_UPDATEFORMATSCHEMAREQUEST = _descriptor.Descriptor(
  name='UpdateFormatSchemaRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1158,
)


_UPDATEFORMATSCHEMAMETADATA = _descriptor.Descriptor(
  name='UpdateFormatSchemaMetadata',
  full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaMetadata.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1236,
)


_DELETEFORMATSCHEMAREQUEST = _descriptor.Descriptor(
  name='DeleteFormatSchemaRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1359,
)


_DELETEFORMATSCHEMAMETADATA = _descriptor.Descriptor(
  name='DeleteFormatSchemaMetadata',
  full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_schema_name', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaMetadata.format_schema_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1437,
)

_LISTFORMATSCHEMASRESPONSE.fields_by_name['format_schemas'].message_type = yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2._FORMATSCHEMA
_CREATEFORMATSCHEMAREQUEST.fields_by_name['type'].enum_type = yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2._FORMATSCHEMATYPE
_UPDATEFORMATSCHEMAREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name['GetFormatSchemaRequest'] = _GETFORMATSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['ListFormatSchemasRequest'] = _LISTFORMATSCHEMASREQUEST
DESCRIPTOR.message_types_by_name['ListFormatSchemasResponse'] = _LISTFORMATSCHEMASRESPONSE
DESCRIPTOR.message_types_by_name['CreateFormatSchemaRequest'] = _CREATEFORMATSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['CreateFormatSchemaMetadata'] = _CREATEFORMATSCHEMAMETADATA
DESCRIPTOR.message_types_by_name['UpdateFormatSchemaRequest'] = _UPDATEFORMATSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['UpdateFormatSchemaMetadata'] = _UPDATEFORMATSCHEMAMETADATA
DESCRIPTOR.message_types_by_name['DeleteFormatSchemaRequest'] = _DELETEFORMATSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['DeleteFormatSchemaMetadata'] = _DELETEFORMATSCHEMAMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFormatSchemaRequest = _reflection.GeneratedProtocolMessageType('GetFormatSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFORMATSCHEMAREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest)
  })
_sym_db.RegisterMessage(GetFormatSchemaRequest)

ListFormatSchemasRequest = _reflection.GeneratedProtocolMessageType('ListFormatSchemasRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORMATSCHEMASREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest)
  })
_sym_db.RegisterMessage(ListFormatSchemasRequest)

ListFormatSchemasResponse = _reflection.GeneratedProtocolMessageType('ListFormatSchemasResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORMATSCHEMASRESPONSE,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse)
  })
_sym_db.RegisterMessage(ListFormatSchemasResponse)

CreateFormatSchemaRequest = _reflection.GeneratedProtocolMessageType('CreateFormatSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORMATSCHEMAREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest)
  })
_sym_db.RegisterMessage(CreateFormatSchemaRequest)

CreateFormatSchemaMetadata = _reflection.GeneratedProtocolMessageType('CreateFormatSchemaMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORMATSCHEMAMETADATA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaMetadata)
  })
_sym_db.RegisterMessage(CreateFormatSchemaMetadata)

UpdateFormatSchemaRequest = _reflection.GeneratedProtocolMessageType('UpdateFormatSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFORMATSCHEMAREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest)
  })
_sym_db.RegisterMessage(UpdateFormatSchemaRequest)

UpdateFormatSchemaMetadata = _reflection.GeneratedProtocolMessageType('UpdateFormatSchemaMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFORMATSCHEMAMETADATA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaMetadata)
  })
_sym_db.RegisterMessage(UpdateFormatSchemaMetadata)

DeleteFormatSchemaRequest = _reflection.GeneratedProtocolMessageType('DeleteFormatSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFORMATSCHEMAREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest)
  })
_sym_db.RegisterMessage(DeleteFormatSchemaRequest)

DeleteFormatSchemaMetadata = _reflection.GeneratedProtocolMessageType('DeleteFormatSchemaMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFORMATSCHEMAMETADATA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaMetadata)
  })
_sym_db.RegisterMessage(DeleteFormatSchemaMetadata)


DESCRIPTOR._options = None
_GETFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
_GETFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
_LISTFORMATSCHEMASREQUEST.fields_by_name['cluster_id']._options = None
_LISTFORMATSCHEMASREQUEST.fields_by_name['page_size']._options = None
_LISTFORMATSCHEMASREQUEST.fields_by_name['page_token']._options = None
_CREATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
_CREATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
_CREATEFORMATSCHEMAREQUEST.fields_by_name['type']._options = None
_CREATEFORMATSCHEMAREQUEST.fields_by_name['uri']._options = None
_UPDATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
_DELETEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
_DELETEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None

_FORMATSCHEMASERVICE = _descriptor.ServiceDescriptor(
  name='FormatSchemaService',
  full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1440,
  serialized_end=2570,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService.Get',
    index=0,
    containing_service=None,
    input_type=_GETFORMATSCHEMAREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2._FORMATSCHEMA,
    serialized_options=b'\202\323\344\223\002Q\022O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService.List',
    index=1,
    containing_service=None,
    input_type=_LISTFORMATSCHEMASREQUEST,
    output_type=_LISTFORMATSCHEMASRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEFORMATSCHEMAREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas:\001*\262\322**\n\032CreateFormatSchemaMetadata\022\014FormatSchema',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEFORMATSCHEMAREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002T2O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}:\001*\262\322**\n\032UpdateFormatSchemaMetadata\022\014FormatSchema',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.clickhouse.v1.FormatSchemaService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEFORMATSCHEMAREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002Q*O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}\262\322*3\n\032DeleteFormatSchemaMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FORMATSCHEMASERVICE)

DESCRIPTOR.services_by_name['FormatSchemaService'] = _FORMATSCHEMASERVICE

# @@protoc_insertion_point(module_scope)
